Welcome to Steam Store Front
============================

Steam Store Front is an easy to use package to get game or app details from steam store.

.. note:: It is not a client. You cannot interact with steam to make purchase or do actions which requires login.*

**Features:**

- Supports apps
- Supports packages
- Supports bundles

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   installation
   functions
   contributing
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`search`
